Learn R Programming

crm12Comb (version 0.1.12)

doseComb_to_mat: Title: Get 6 complete orderings for toxicity and efficacy for drug combinations

Description

Step 1: convert dose combinations into matrix

Usage

doseComb_to_mat(doseComb, type)

Value

outMat -> Either a list or a matrix. Note: each array refers to the index of drug combinations orderings)

Arguments

doseComb

Either a numeric matrix or a numeric vector or a numeric list.

type

A string. condition 1: detailed dose combinations are directly given in matrix -> type = "comb" dose combinations dose A dose B condition 2: directly given the number of levels for the two doses in vector -> type = "matrix"

Step 2: get the 6 orderings

References

Wages NA, Conaway MR. Specifications of a continual reassessment method design for phase I trials of combined drugs. Pharmaceutical statistics. 2013 Jul;12(4):217-24. tools:::Rd_expr_doi("10.1002/pst.1575")