- updelta
The half-width of the indifference intervals.
- target
The target DLT rate.
- npos
The prior guess of the position of MTD.
- ndose
The number of testing doses.
- model
A character string to specify the model used. The default model is "empiric". Other models include hyperbolic tangent model specified by "tanh", one-parameter logistic model specified by "logistic", and two-parameter logistic model specified by "logistic2".
- prior
A character sting to specify the prior distribution of parameter. The default prior is "normal" used together with the model="empiric". Other prior distributions include "exponential" when model="tanh", "gamma" when model="empiric", "normal" and "gamma" when model="logistic" and "logistic2".
- alpha_mean
The mean of intercept parameter of two-parameter logistic model only used when model="logistic2" and prior="normal", otherwise will be ignored.
- beta_mean
The mean of parameter used when prior="exponential" or "normal", otherwise will be ignored.
- a0
A constant value of intercept from a one-parameter logistic model only used when model="logistic" with default value 3, otherwise will be ignored.
- alpha_shape
The shape parameter of intercept parameter only used when model="logistic2" and prior="gamma", otherwise will be ignored.
- alpha_inverse_scale
The scale parameter of intercept parameter only used when model="logistic2" and prior="gamma", otherwise will be ignored.
- beta_shape
The shape parameter used when prior="gamma", otherwise will be ignored.
- beta_inverse_scale
The scale parameter used when prior="gamma", otherwise will be ignored.